@@ -14,12 +14,6 @@ sub env : Action Relative {
     $c->forward('TestApp::View::Dump::Env');
 }
 
-sub env_on_engine : Action Relative {
-    my ( $self, $c ) = @_;
-    $c->stash(env => $c->engine->env);
-    $c->forward('TestApp::View::Dump::Env');
-}
-
 sub request : Action Relative {
     my ( $self, $c ) = @_;
     $c->req->params(undef); # Should be a no-op, and be ignored.
