@@ -1,7 +1,7 @@
 package TestApp::Plugin::ParameterizedRole;
 
 use MooseX::Role::Parameterized;
-use namespace::clean -except => [ 'meta' ];
+use namespace::autoclean;
 
 parameter method_name => (
     isa      => 'Str',
